@@ -4,7 +4,7 @@ from .views import SwaggerView, ResourcesView, SchemaView
 
 urlpatterns = patterns('',
     url(r'^$', SwaggerView.as_view(), name='index'),
-    url(r'^resources.json$', ResourcesView.as_view(), name='resources'),
+    url(r'^resources/$', ResourcesView.as_view(), name='resources'),
     url(r'^schema/(?P<resource>\S+)/$', SchemaView.as_view()),
     url(r'^schema/$', SchemaView.as_view(), name='schema'),
 )
